trans = read.csv('../selection-presentation-transformations.csv', header=TRUE,  sep="\t")

trans$transformation=as.character(trans$transformation)

print.result =function(write.to.file, param.trans.match, filename) {  
  print(paste("-------------------------------", sep=""))
    
  trans.subset = trans[which(trans$transformation %in% param.trans.match),c("user","sid","transformation")]
  aggr= aggregate(sid~user, data=trans.subset, FUN=function(x){length(unique(x))});
  aggr=aggr[order(-aggr$sid),];  
  data.for.icon=data.frame(participants=1:length(aggr$sid), code.fragments=aggr$sid);
  participants=aggr$user[order(aggr$user)];   
  
  result = list(transformations=param.trans.match, 
    nbr.fragments=length(unique(trans.subset$sid)), 
  	nbr.participants=length(unique(trans.subset$user)), 
  	nbr.instances=dim(trans.subset)[1],
  	aggregate=aggr,
  	data.for.icon=data.for.icon,
  	participants=participants);
  
  if( write.to.file) {
  	write.table(data.for.icon, file = filename, sep = " ", row.names=FALSE, col.names=FALSE, quote=FALSE)
  }
  print(result);
  
  return(result);
}

print.to.file=TRUE;



################### Trimming #####################################

transformations.6.1.1=c("rename-refactoring on a parameter (shortened)",
	"rename-refactoring on a variable (shortened)",
	"change variable name (shorten)");
transformations.6.1.2=c("shorten method declaration name (API)",
	"shorten method name (API)");
transformations.6.1.3=c("remove type qualifier",
	"remove variable type in assignment",
	"remove cast in assignment",
	"shorten type name")
transformations.6.1=c(transformations.6.1.1,transformations.6.1.2,transformations.6.1.3);
		
data.6.1.1=print.result(print.to.file, transformations.6.1.1, "icon-data-shorten-identifiers.csv")
data.6.1.2=print.result(print.to.file, transformations.6.1.2, "icon-data-shorten-api-names.csv")
data.6.1.3=print.result(print.to.file, transformations.6.1.3, "icon-data-eliding-type-information.csv")
data.6.1=print.result(print.to.file, transformations.6.1, "icon-data-trimming.csv")		
	
	
################### Compressing #####################################

transformations.6.2.1=c("replace method body with ...",
	"replace method body with comment",
	"replace statements with ...",
	"replace statements with comment (or place-holder)");
transformations.6.2.2=c("replace method declaration with ...",
	"replace method declaration with comment",
	"replace method signature with comment",
	"replace method body with comment");
transformations.6.2.3=c("replace conditional body with ...",
	"replace conditional body with comment",
	"reorganize conditional structure -switch to if",
	"reorganize conditional structure - if to conditional expression")
transformations.6.2=c(transformations.6.2.1,transformations.6.2.2,transformations.6.2.3);
		
data.6.2.1=print.result(print.to.file, transformations.6.2.1, "icon-data-shorten-multiple-statements.csv")
data.6.2.2=print.result(print.to.file, transformations.6.2.2, "icon-data-shorten-method-declarations.csv")
data.6.2.3=print.result(print.to.file, transformations.6.2.3, "icon-data-shorten-control-structures.csv")
data.6.2=print.result(print.to.file, transformations.6.2, "icon-data-compressing.csv")			


################### Truncating #####################################

transformations.6.3.1=c("replace parameters in method call with ...",
	"remove parameters in method call",
	"replace parameters in method declaration with ...",
	"remove parameters in method declaration")
data.6.3.1=print.result(print.to.file, transformations.6.3.1, "icon-data-eliminating-parameter.csv")

transformations.6.3.2=c("remove keywords from class declaration",
"replace keywords from class declaration with ...",
"replace keywords from method declaration with ...",
"remove keywords from method declaration");
data.6.3.2=print.result(print.to.file, transformations.6.3.2, "icon-data-truncating-signature.csv");

transformations.6.3=c(transformations.6.3.1,transformations.6.3.2);
data.6.3=print.result(print.to.file, transformations.6.3, "icon-data-truncating.csv");


#################### Improving Code ###################
	
transformations.6.5.1=c("reorganize conditional structure - consolidate conditional fragments",
	"reorganize conditional structure - consolidate duplicate conditional fragments");
transformations.6.5.2=c("replace constant with variable",
	"replace variable with place-holder (abstract)");
transformations.6.5.3=c("rename-refactoring on a variable (lengthened)",
	"change variable name (lengthened)",
	"add comment (clarify)",
	"add comment (reiterate)");
transformations.6.5=c(transformations.6.5.1,transformations.6.5.2,transformations.6.5.3);

data.6.5.1=print.result(print.to.file, transformations.6.5.1, "icon-data-refactoring.csv")
data.6.5.2=print.result(print.to.file, transformations.6.5.2, "icon-data-generalization.csv")
data.6.5.3=print.result(print.to.file, transformations.6.5.3, "icon-data-clarification.csv")
data.6.5=print.result(print.to.file, transformations.6.5, "icon-data-improving.csv")


################### extractive / abstractive #####################################

transformations.6.1.and.6.2=c(transformations.6.1, transformations.6.2)
print.result(print.to.file, transformations.6.1.and.6.2, "icon-data-trimming-and-compressing.csv")


transformations.extractive=c(transformations.6.1, transformations.6.2, transformations.6.3)
data.extractive=print.result(print.to.file, transformations.extractive, "icon-data-extractive.csv");



################### comment / code transformation #####################################

# in Compressing and Truncating
transformations.natural.language.text=c(
	"replace method body with comment",
	"replace statements with comment (or place-holder)",
	"replace method declaration with comment",
	"replace method signature with comment",
	"replace method body with comment",
	"replace conditional body with comment");
		
data.natural.language.text=print.result(TRUE, transformations.natural.language.text, 
	"icon-data-natural-language-text.csv")

		